.. _testing:

Test Case Descriptions
======================

----------------
How to run tests
----------------

**1. Run full test suite**::

    $ python manage.py test --verbosity=2

**2. Run AdminToolsStatsAdminInterfaceTestCase**::

    $ python manage.py test admin_tools_stats.AdminToolsStatsAdminInterfaceTestCase --verbosity=2


---------
Test Case
---------

.. _AdminToolsStatsAdminInterfaceTestCase-model:

:class:`AdminToolsStatsAdminInterfaceTestCase`
----------------------------------------------

Test cases for django-admin-tools-stats Admin Interface.
